torvyn bench — benchmark a pipeline.
Runs a pipeline under sustained load with warmup period, then produces a performance report with latency percentiles, throughput, resource usage, and scheduling statistics.
Structs
- Bench
Report - Complete benchmark report.
- Component
Bench Row - Per-component latency in a benchmark.
- Latency
Report - Latency percentile metrics.
- Resource
Report - Resource usage metrics.
- Scheduling
Report - Scheduling metrics.
- Throughput
Report - Throughput metrics.
Functions
- execute
- Execute the
torvyn benchcommand.