pub fn render_table<T: Tabled>(ctx: &OutputContext, items: &[T])Expand description
Render a table from a list of items to stderr.
COLD PATH — called by bench, inspect, doctor.
pub fn render_table<T: Tabled>(ctx: &OutputContext, items: &[T])Render a table from a list of items to stderr.
COLD PATH — called by bench, inspect, doctor.