Template registry and expansion for torvyn init.
Templates are embedded in the binary. Each template provides a complete set of files needed for a specific component pattern.
Modules
- content
- Embedded template file contents.
Structs
- Template
- The complete set of files for a template.
- Template
File - A single file in a template, with its relative path and content.
- Template
Vars - Substitution variables available to templates.
Functions
- expand_
template - Expand a template into real files at the specified directory.
- get_
template - Get the template for the given kind.
- substitute
- Apply variable substitution to a template string.
- to_
pascal_ case - Convert a kebab-case string to PascalCase.