Module bench

Module bench 

torvyn bench — benchmark a pipeline.

Runs a pipeline under sustained load with warmup period, then produces a performance report with latency percentiles, throughput, resource usage, and scheduling statistics.

Structs

BenchReport
Complete benchmark report.
ComponentBenchRow
Per-component latency in a benchmark.
LatencyReport
Latency percentile metrics.
ResourceReport
Resource usage metrics.
SchedulingReport
Scheduling metrics.
ThroughputReport
Throughput metrics.

Functions

execute
Execute the torvyn bench command.